"use client"

import { createContext, useContext, useState, useEffect, type ReactNode } from "react"
import { useRouter } from "next/navigation"

type User = {
  id: number
  username: string
  name: string
  email?: string
  role: string
  planType: string
  expirationDate?: string
}

type AuthContextType = {
  user: User | null
  isLoading: boolean
  subscriptionExpired: boolean
  login: (username: string, password: string) => Promise<boolean>
  logout: () => void
  renewSubscription: () => void
}

const AuthContext = createContext<AuthContextType | undefined>(undefined)

export function AuthProvider({ children }: { children: ReactNode }) {
  const [user, setUser] = useState<User | null>(null)
  const [isLoading, setIsLoading] = useState(true)
  const [subscriptionExpired, setSubscriptionExpired] = useState(false)
  const router = useRouter()

  useEffect(() => {
    // Vérifier si l'utilisateur est déjà connecté
    const storedUser = localStorage.getItem("user")
    if (storedUser) {
      const userData = JSON.parse(storedUser)

      // Vérifier si l'abonnement a expiré
      if (userData.expirationDate && new Date() > new Date(userData.expirationDate)) {
        setSubscriptionExpired(true)
        localStorage.removeItem("user")
        setUser(null)
      } else {
        setUser(userData)
      }
    }
    setIsLoading(false)
  }, [])

  const login = async (username: string, password: string) => {
    try {
      setIsLoading(true)
      setSubscriptionExpired(false)

      // Appeler l'API d'authentification
      const response = await fetch("/api/auth/login", {
        method: "POST",
        headers: {
          "Content-Type": "application/json",
        },
        body: JSON.stringify({ username, password }),
        credentials: "include", // <-- Pour que le cookie soit bien enregistré
      })

      const data = await response.json()

      if (response.status === 403 && data.expired) {
        setSubscriptionExpired(true)
        return false
      }

      if (!response.ok) {
        return false
      }

      setUser(data)
      localStorage.setItem("user", JSON.stringify(data))
      return true
    } catch (error) {
      console.error("Erreur de connexion:", error)
      return false
    } finally {
      setIsLoading(false)
    }
  }

  const logout = () => {
    setUser(null)
    localStorage.removeItem("user")
    router.push("/login")
  }

  const renewSubscription = () => {
    // Cette fonction serait implémentée pour renouveler l'abonnement
    // Pour l'instant, on réinitialise juste l'état
    setSubscriptionExpired(false)
    router.push("/subscription")
  }

  return (
    <AuthContext.Provider
      value={{
        user,
        isLoading,
        subscriptionExpired,
        login,
        logout,
        renewSubscription,
      }}
    >
      {children}
    </AuthContext.Provider>
  )
}

export function useAuth() {
  const context = useContext(AuthContext)
  if (context === undefined) {
    throw new Error("useAuth doit être utilisé à l'intérieur d'un AuthProvider")
  }
  return context
}
